@@ -1,9 +1,7 @@
-from enum import StrEnum
-
-
-class BlockType(StrEnum):
+class BlockType:
     IMPORT = "import"
     FUNCTION = "function"
     CLASS = "class"
     VALUE = "value"
     COMMENT = "comment"
+    OTHER = "other"
