@@ -2,7 +2,9 @@ from dataclasses import dataclass
 from pathlib import Path
 
 from src.entities.block import Block
-from src.services.generate_import_statement_service import GenerateImportStatementService
+from src.services.generate_import_statement_service import (
+    GenerateImportStatementService,
+)
 
 
 @dataclass(frozen=True)
